@@ -15,6 +15,9 @@ You should have received a copy of the GNU Lesser General Public License along
 with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
+import numpy as np
+import pytest
+import re
 from .fixtures import *
 from collections import deque
 from decimal import Decimal
@@ -27,9 +30,6 @@ from pybroker.context import (
     set_pos_size_ctx_data,
 )
 from pybroker.portfolio import Order, Portfolio, Position, Trade
-import numpy as np
-import pytest
-import re
 
 
 @pytest.fixture()
@@ -421,12 +421,20 @@ def test_long_positions(ctx_with_pos, symbol):
     assert positions[0] == Position(symbol, 200, "long")
 
 
+def test_long_positions_when_empty(ctx, symbol):
+    assert not len(tuple(ctx.long_positions(symbol)))
+
+
 def test_short_positions(ctx_with_pos, symbol):
     positions = tuple(ctx_with_pos.short_positions(symbol))
     assert len(positions) == 1
     assert positions[0] == Position(symbol, 100, "short")
 
 
+def test_short_positions_when_empty(ctx, symbol):
+    assert not len(tuple(ctx.short_positions(symbol)))
+
+
 def test_calc_target_shares(ctx):
     assert ctx.calc_target_shares(0.5, 33.50) == 50_000 // 33.5
 
